@@ -130,6 +130,7 @@ SENSOR_MAP: dict[str, EcoWittMapping] = {
         "Monthly Rain", EcoWittSensorTypes.RAIN_COUNT_INCHES
     ),
     "yearlyrainin": EcoWittMapping("Yearly Rain", EcoWittSensorTypes.RAIN_COUNT_INCHES),
+    "last24hrainin": EcoWittMapping("24h Rain", EcoWittSensorTypes.RAIN_COUNT_INCHES),
     "rainratemm": EcoWittMapping("Rain Rate", EcoWittSensorTypes.RAIN_RATE_MM),
     "eventrainmm": EcoWittMapping("Event Rain", EcoWittSensorTypes.RAIN_COUNT_MM),
     "hourlyrainmm": EcoWittMapping("Hourly Rain", EcoWittSensorTypes.RAIN_COUNT_MM),
@@ -138,6 +139,7 @@ SENSOR_MAP: dict[str, EcoWittMapping] = {
     "weeklyrainmm": EcoWittMapping("Weekly Rain", EcoWittSensorTypes.RAIN_COUNT_MM),
     "monthlyrainmm": EcoWittMapping("Monthly Rain", EcoWittSensorTypes.RAIN_COUNT_MM),
     "yearlyrainmm": EcoWittMapping("Yearly Rain", EcoWittSensorTypes.RAIN_COUNT_MM),
+    "last24hrainmm": EcoWittMapping("24h Rain", EcoWittSensorTypes.RAIN_COUNT_MM),
     "humidity": EcoWittMapping("Humidity", EcoWittSensorTypes.HUMIDITY),
     "humidityin": EcoWittMapping("Indoor Humidity", EcoWittSensorTypes.HUMIDITY),
     "humidity1": EcoWittMapping("Humidity 1", EcoWittSensorTypes.HUMIDITY),
@@ -544,6 +546,9 @@ SENSOR_MAP: dict[str, EcoWittMapping] = {
     "yrain_piezo": EcoWittMapping(
         "Yearly Rain Piezo", EcoWittSensorTypes.RAIN_COUNT_INCHES
     ),
+    "last24hrain_piezo": EcoWittMapping(
+        "24h Rain Piezo", EcoWittSensorTypes.RAIN_COUNT_INCHES
+    ),
     "srain_piezo": EcoWittMapping("Rain State Piezo", EcoWittSensorTypes.RAIN_STATE),
     "rrain_piezomm": EcoWittMapping("Rain Rate Piezo", EcoWittSensorTypes.RAIN_RATE_MM),
     "erain_piezomm": EcoWittMapping(
@@ -564,6 +569,9 @@ SENSOR_MAP: dict[str, EcoWittMapping] = {
     "yrain_piezomm": EcoWittMapping(
         "Yearly Rain Piezo", EcoWittSensorTypes.RAIN_COUNT_MM
     ),
+    "last24hrain_piezomm": EcoWittMapping(
+        "24h Rain Piezo", EcoWittSensorTypes.RAIN_COUNT_MM
+    ),
     "runtime": EcoWittMapping("Runtime", EcoWittSensorTypes.INTERNAL),
     "interval": EcoWittMapping("Interval", EcoWittSensorTypes.INTERNAL),
     "heap": EcoWittMapping("Memory heap", EcoWittSensorTypes.INTERNAL),
